count_unlinked_enrolled_students_for_course

Function count_unlinked_enrolled_students_for_course 

pub async fn count_unlinked_enrolled_students_for_course(
    conn: &mut PgConnection,
    course_id: Uuid,
) -> ModelResult<i64>
Enrolled students of the course who hold no live student number link, and so cannot have credits registered for them until they link one.