get_by_sisu_person_ids

Function get_by_sisu_person_ids 

pub async fn get_by_sisu_person_ids(
    conn: &mut PgConnection,
    sisu_person_ids: &[String],
) -> ModelResult<Vec<VerifiedStudentNumber>>
The person id rather than the number, because the number changes when a student moves between programmes while the person id does not.